@@ -83,8 +83,12 @@ namespace SourceGit
             if (ex == null)
                 return;
 
+            var crashDir = Path.Combine(Native.OS.DataDir, "crashes");
+            if (!Directory.Exists(crashDir))
+                Directory.CreateDirectory(crashDir);
+
             var time = DateTime.Now.ToString("yyyy-MM-dd_HH-mm-ss");
-            var file = Path.Combine(Native.OS.DataDir, $"crash_{time}.log");
+            var file = Path.Combine(crashDir, $"{time}.log");
             using var writer = new StreamWriter(file);
             writer.WriteLine($"Crash::: {ex.GetType().FullName}: {ex.Message}");
             writer.WriteLine();
@@ -94,7 +98,6 @@ namespace SourceGit
             writer.WriteLine($"Framework: {AppDomain.CurrentDomain.SetupInformation.TargetFrameworkName}");
             writer.WriteLine($"Source: {ex.Source}");
             writer.WriteLine($"Thread Name: {Thread.CurrentThread.Name ?? "Unnamed"}");
-            writer.WriteLine($"User: {Environment.UserName}");
             writer.WriteLine($"App Start Time: {Process.GetCurrentProcess().StartTime}");
             writer.WriteLine($"Exception Time: {DateTime.Now}");
             writer.WriteLine($"Memory Usage: {Process.GetCurrentProcess().PrivateMemorySize64 / 1024 / 1024} MB");
@@ -145,26 +148,60 @@ namespace SourceGit
 
         public static void ShowWindow(object data)
         {
-            if (data is Views.ChromelessWindow window)
+            if (data is not Views.ChromelessWindow window)
             {
-                window.Show();
-                return;
+                window = CreateViewForViewModel(data) as Views.ChromelessWindow;
+                if (window == null)
+                    return;
+
+                window.DataContext = data;
             }
 
-            window = CreateViewForViewModel(data) as Views.ChromelessWindow;
-            if (window != null)
+            do
             {
-                window.DataContext = data;
-                window.Show();
-            }
+                if (Current?.ApplicationLifetime is IClassicDesktopStyleApplicationLifetime { Windows: { Count: > 0 } windows })
+                {
+                    // Try to find the actived window (fall back to `MainWindow`)
+                    Window actived = windows[0];
+                    if (!actived.IsActive)
+                    {
+                        for (var i = 1; i < windows.Count; i++)
+                        {
+                            var test = windows[i];
+                            if (test.IsActive)
+                            {
+                                actived = test;
+                                break;
+                            }
+                        }
+                    }
+
+                    // Get the screen where current window locates.
+                    var screen = actived.Screens.ScreenFromWindow(actived) ?? actived.Screens.Primary;
+                    if (screen == null)
+                        break;
+
+                    // Calculate the startup position (Center Screen Mode) of target window
+                    var rect = new PixelRect(PixelSize.FromSize(window.ClientSize, actived.DesktopScaling));
+                    var centeredRect = screen.WorkingArea.CenterRect(rect);
+                    if (actived.Screens.ScreenFromPoint(centeredRect.Position) == null)
+                        break;
+
+                    // Use the startup position
+                    window.WindowStartupLocation = WindowStartupLocation.Manual;
+                    window.Position = centeredRect.Position;
+                }
+            } while (false);
+
+            window.Show();
         }
 
-        public static async Task<bool> AskConfirmAsync(string message)
+        public static async Task<bool> AskConfirmAsync(string message, Models.ConfirmButtonType buttonType = Models.ConfirmButtonType.OkCancel)
         {
             if (Current?.ApplicationLifetime is IClassicDesktopStyleApplicationLifetime { MainWindow: { } owner })
             {
                 var confirm = new Views.Confirm();
-                confirm.Message.Text = message;
+                confirm.SetData(message, buttonType);
                 return await confirm.ShowDialog<bool>(owner);
             }
 
@@ -390,6 +427,9 @@ namespace SourceGit
                 if (TryLaunchAsFileHistoryViewer(desktop))
                     return;
 
+                if (TryLaunchAsBlameViewer(desktop))
+                    return;
+
                 if (TryLaunchAsCoreEditor(desktop))
                     return;
 
@@ -543,6 +583,41 @@ namespace SourceGit
             return true;
         }
 
+        private bool TryLaunchAsBlameViewer(IClassicDesktopStyleApplicationLifetime desktop)
+        {
+            var args = desktop.Args;
+            if (args is not { Length: > 1 } || !args[0].Equals("--blame", StringComparison.Ordinal))
+                return false;
+
+            var file = Path.GetFullPath(args[1]);
+            var dir = Path.GetDirectoryName(file);
+
+            var test = new Commands.QueryRepositoryRootPath(dir).GetResult();
+            if (!test.IsSuccess || string.IsNullOrEmpty(test.StdOut))
+            {
+                Console.Out.WriteLine($"'{args[1]}' is not in a valid git repository");
+                desktop.Shutdown(-1);
+                return true;
+            }
+
+            var repo = test.StdOut.Trim();
+            var head = new Commands.QuerySingleCommit(repo, "HEAD").GetResult();
+            if (head == null)
+            {
+                Console.Out.WriteLine($"{repo} has no commits!");
+                desktop.Shutdown(-1);
+                return true;
+            }
+
+            var relFile = Path.GetRelativePath(repo, file);
+            var viewer = new Views.Blame()
+            {
+                DataContext = new ViewModels.Blame(repo, relFile, head)
+            };
+            desktop.MainWindow = viewer;
+            return true;
+        }
+
         private bool TryLaunchAsCoreEditor(IClassicDesktopStyleApplicationLifetime desktop)
         {
             var args = desktop.Args;
