@@ -43,15 +43,13 @@ namespace SourceGit.Commands
             return await ExecAsync().ConfigureAwait(false);
         }
 
-        public async Task<bool> UpdateAsync(List<string> modules, bool init, bool recursive, bool useRemote = false)
+        public async Task<bool> UpdateAsync(List<string> modules, bool init = false, bool useRemote = false)
         {
             var builder = new StringBuilder();
-            builder.Append("submodule update");
+            builder.Append("submodule update --recursive");
 
             if (init)
                 builder.Append(" --init");
-            if (recursive)
-                builder.Append(" --recursive");
             if (useRemote)
                 builder.Append(" --remote");
             if (modules.Count > 0)
