@@ -12,15 +12,28 @@ namespace SourceGit.Models
 {
     public class ExternalTool
     {
+        public class LaunchOption
+        {
+            public string Title { get; set; }
+            public string Args { get; set; }
+
+            public LaunchOption(string title, string args)
+            {
+                Title = title;
+                Args = args;
+            }
+        }
+
         public string Name { get; }
         public string ExecFile { get; }
         public Bitmap IconImage { get; }
 
-        public ExternalTool(string name, string icon, string execFile, Func<string, string> execArgsGenerator = null)
+        public ExternalTool(string name, string icon, string execFile, Func<string, List<LaunchOption>> optionsGenerator = null)
         {
             Name = name;
             ExecFile = execFile;
-            _execArgsGenerator = execArgsGenerator ?? (path => path.Quoted());
+
+            _optionsGenerator = optionsGenerator;
 
             try
             {
@@ -34,17 +47,25 @@ namespace SourceGit.Models
             }
         }
 
-        public void Open(string path)
+        public List<LaunchOption> MakeLaunchOptions(string repo)
         {
-            Process.Start(new ProcessStartInfo()
-            {
-                FileName = ExecFile,
-                Arguments = _execArgsGenerator.Invoke(path),
-                UseShellExecute = false,
-            });
+            return _optionsGenerator?.Invoke(repo);
         }
 
-        private Func<string, string> _execArgsGenerator = null;
+        public void Launch(string args)
+        {
+            if (File.Exists(ExecFile))
+            {
+                Process.Start(new ProcessStartInfo()
+                {
+                    FileName = ExecFile,
+                    Arguments = args,
+                    UseShellExecute = false,
+                });
+            }
+        }
+
+        private Func<string, List<LaunchOption>> _optionsGenerator = null;
     }
 
     public class VisualStudioInstance
@@ -91,10 +112,12 @@ namespace SourceGit.Models
         public string LaunchCommand { get; set; }
     }
 
-    public class ExternalToolPaths
+    public class ExternalToolCustomization
     {
         [JsonPropertyName("tools")]
         public Dictionary<string, string> Tools { get; set; } = new Dictionary<string, string>();
+        [JsonPropertyName("excludes")]
+        public List<string> Excludes { get; set; } = new List<string>();
     }
 
     public class ExternalToolsFinder
@@ -113,7 +136,7 @@ namespace SourceGit.Models
                 if (File.Exists(customPathsConfig))
                 {
                     using var stream = File.OpenRead(customPathsConfig);
-                    _customPaths = JsonSerializer.Deserialize(stream, JsonCodeGen.Default.ExternalToolPaths);
+                    _customization = JsonSerializer.Deserialize(stream, JsonCodeGen.Default.ExternalToolCustomization);
                 }
             }
             catch
@@ -121,41 +144,39 @@ namespace SourceGit.Models
                 // Ignore
             }
 
-            _customPaths ??= new ExternalToolPaths();
+            _customization ??= new ExternalToolCustomization();
         }
 
-        public void TryAdd(string name, string icon, Func<string> finder, Func<string, string> execArgsGenerator = null)
+        public void TryAdd(string name, string icon, Func<string> finder, Func<string, List<ExternalTool.LaunchOption>> optionsGenerator = null)
         {
-            if (_customPaths.Tools.TryGetValue(name, out var customPath) && File.Exists(customPath))
+            if (_customization.Excludes.Contains(name))
+                return;
+
+            if (_customization.Tools.TryGetValue(name, out var customPath) && File.Exists(customPath))
             {
-                Tools.Add(new ExternalTool(name, icon, customPath, execArgsGenerator));
+                Tools.Add(new ExternalTool(name, icon, customPath, optionsGenerator));
             }
             else
             {
                 var path = finder();
                 if (!string.IsNullOrEmpty(path) && File.Exists(path))
-                    Tools.Add(new ExternalTool(name, icon, path, execArgsGenerator));
+                    Tools.Add(new ExternalTool(name, icon, path, optionsGenerator));
             }
         }
 
         public void VSCode(Func<string> platformFinder)
         {
-            TryAdd("Visual Studio Code", "vscode", platformFinder);
+            TryAdd("Visual Studio Code", "vscode", platformFinder, GenerateVSCodeLaunchOptions);
         }
 
         public void VSCodeInsiders(Func<string> platformFinder)
         {
-            TryAdd("Visual Studio Code - Insiders", "vscode_insiders", platformFinder);
+            TryAdd("Visual Studio Code - Insiders", "vscode_insiders", platformFinder, GenerateVSCodeLaunchOptions);
         }
 
         public void VSCodium(Func<string> platformFinder)
         {
-            TryAdd("VSCodium", "codium", platformFinder);
-        }
-
-        public void Fleet(Func<string> platformFinder)
-        {
-            TryAdd("Fleet", "fleet", platformFinder);
+            TryAdd("VSCodium", "codium", platformFinder, GenerateVSCodeLaunchOptions);
         }
 
         public void SublimeText(Func<string> platformFinder)
@@ -202,6 +223,21 @@ namespace SourceGit.Models
             }
         }
 
-        private ExternalToolPaths _customPaths = null;
+        private List<ExternalTool.LaunchOption> GenerateVSCodeLaunchOptions(string path)
+        {
+            var root = new DirectoryInfo(path);
+            if (!root.Exists)
+                return null;
+
+            var options = new List<ExternalTool.LaunchOption>();
+            root.WalkFiles(f =>
+            {
+                if (f.EndsWith(".code-workspace", StringComparison.OrdinalIgnoreCase))
+                    options.Add(new(root.GetRelativePath(f), f.Quoted()));
+            }, 2);
+            return options;
+        }
+
+        private ExternalToolCustomization _customization = null;
     }
 }
