@@ -1,4 +1,11 @@
+using System;
 using System.Collections.Generic;
+using System.IO;
+using System.Security.Cryptography;
+using System.Text;
+using System.Text.Json;
+using System.Threading.Tasks;
+
 using Avalonia.Collections;
 
 namespace SourceGit.Models
@@ -11,101 +18,41 @@ namespace SourceGit.Models
             set;
         } = string.Empty;
 
-        public HistoryShowFlags HistoryShowFlags
+        public int PreferredMergeMode
         {
             get;
             set;
-        } = HistoryShowFlags.None;
+        } = 0;
 
-        public bool EnableTopoOrderInHistories
+        public string ConventionalTypesOverride
+        {
+            get;
+            set;
+        } = string.Empty;
+
+        public bool EnableAutoFetch
         {
             get;
             set;
         } = false;
 
-        public bool OnlyHighlightCurrentBranchInHistories
+        public int AutoFetchInterval
+        {
+            get;
+            set;
+        } = 10;
+
+        public bool AskBeforeAutoUpdatingSubmodules
         {
             get;
             set;
         } = false;
 
-        public BranchSortMode LocalBranchSortMode
+        public string PreferredOpenAIService
         {
             get;
             set;
-        } = BranchSortMode.Name;
-
-        public BranchSortMode RemoteBranchSortMode
-        {
-            get;
-            set;
-        } = BranchSortMode.Name;
-
-        public TagSortMode TagSortMode
-        {
-            get;
-            set;
-        } = TagSortMode.CreatorDate;
-
-        public bool IncludeUntrackedInLocalChanges
-        {
-            get;
-            set;
-        } = true;
-
-        public bool EnableForceOnFetch
-        {
-            get;
-            set;
-        } = false;
-
-        public bool FetchAllRemotes
-        {
-            get;
-            set;
-        } = false;
-
-        public bool FetchWithoutTags
-        {
-            get;
-            set;
-        } = false;
-
-        public bool PreferRebaseInsteadOfMerge
-        {
-            get;
-            set;
-        } = true;
-
-        public bool CheckSubmodulesOnPush
-        {
-            get;
-            set;
-        } = true;
-
-        public bool PushAllTags
-        {
-            get;
-            set;
-        } = false;
-
-        public bool PushToRemoteWhenCreateTag
-        {
-            get;
-            set;
-        } = true;
-
-        public bool PushToRemoteWhenDeleteTag
-        {
-            get;
-            set;
-        } = false;
-
-        public bool CheckoutBranchOnCreateBranch
-        {
-            get;
-            set;
-        } = true;
+        } = "---";
 
         public AvaloniaList<CommitTemplate> CommitTemplates
         {
@@ -125,107 +72,59 @@ namespace SourceGit.Models
             set;
         } = [];
 
-        public bool EnableAutoFetch
+        public static RepositorySettings Get(string gitCommonDir)
         {
-            get;
-            set;
-        } = false;
+            var fileInfo = new FileInfo(Path.Combine(gitCommonDir, "sourcegit.settings"));
+            var fullpath = fileInfo.FullName;
+            if (_cache.TryGetValue(fullpath, out var setting))
+                return setting;
 
-        public int AutoFetchInterval
-        {
-            get;
-            set;
-        } = 10;
+            if (!File.Exists(fullpath))
+            {
+                setting = new();
+            }
+            else
+            {
+                try
+                {
+                    using var stream = File.OpenRead(fullpath);
+                    setting = JsonSerializer.Deserialize(stream, JsonCodeGen.Default.RepositorySettings);
+                }
+                catch
+                {
+                    setting = new();
+                }
+            }
 
-        public bool EnableSignOffForCommit
-        {
-            get;
-            set;
-        } = false;
+            // Serialize setting again to make sure there are no unnecessary whitespaces.
+            Task.Run(() =>
+            {
+                var formatted = JsonSerializer.Serialize(setting, JsonCodeGen.Default.RepositorySettings);
+                setting._orgHash = HashContent(formatted);
+            });
 
-        public bool NoVerifyOnCommit
-        {
-            get;
-            set;
-        } = false;
+            setting._file = fullpath;
+            _cache.Add(fullpath, setting);
+            return setting;
+        }
 
-        public bool IncludeUntrackedWhenStash
+        public async Task SaveAsync()
         {
-            get;
-            set;
-        } = true;
-
-        public bool OnlyStagedWhenStash
-        {
-            get;
-            set;
-        } = false;
-
-        public int ChangesAfterStashing
-        {
-            get;
-            set;
-        } = 0;
-
-        public string PreferredOpenAIService
-        {
-            get;
-            set;
-        } = "---";
-
-        public bool IsLocalBranchesExpandedInSideBar
-        {
-            get;
-            set;
-        } = true;
-
-        public bool IsRemotesExpandedInSideBar
-        {
-            get;
-            set;
-        } = false;
-
-        public bool IsTagsExpandedInSideBar
-        {
-            get;
-            set;
-        } = false;
-
-        public bool IsSubmodulesExpandedInSideBar
-        {
-            get;
-            set;
-        } = false;
-
-        public bool IsWorktreeExpandedInSideBar
-        {
-            get;
-            set;
-        } = false;
-
-        public List<string> ExpandedBranchNodesInSideBar
-        {
-            get;
-            set;
-        } = [];
-
-        public int PreferredMergeMode
-        {
-            get;
-            set;
-        } = 0;
-
-        public string LastCommitMessage
-        {
-            get;
-            set;
-        } = string.Empty;
-
-        public string ConventionalTypesOverride
-        {
-            get;
-            set;
-        } = string.Empty;
+            try
+            {
+                var content = JsonSerializer.Serialize(this, JsonCodeGen.Default.RepositorySettings);
+                var hash = HashContent(content);
+                if (!hash.Equals(_orgHash, StringComparison.Ordinal))
+                {
+                    await File.WriteAllTextAsync(_file, content);
+                    _orgHash = hash;
+                }
+            }
+            catch
+            {
+                // Ignore save errors
+            }
+        }
 
         public void PushCommitMessage(string message)
         {
@@ -272,5 +171,18 @@ namespace SourceGit.Models
             if (idx < CustomActions.Count - 1)
                 CustomActions.Move(idx + 1, idx);
         }
+
+        private static string HashContent(string source)
+        {
+            var hash = MD5.HashData(Encoding.Default.GetBytes(source));
+            var builder = new StringBuilder(hash.Length * 2);
+            foreach (var c in hash)
+                builder.Append(c.ToString("x2"));
+            return builder.ToString();
+        }
+
+        private static Dictionary<string, RepositorySettings> _cache = new();
+        private string _file = string.Empty;
+        private string _orgHash = string.Empty;
     }
 }
