@@ -37,7 +37,7 @@ namespace SourceGit.Models
                 var combined = new FileSystemWatcher();
                 combined.Path = fullpath;
                 combined.Filter = "*";
-                combined.NotifyFilter = NotifyFilters.LastWrite | NotifyFilters.DirectoryName | NotifyFilters.FileName | NotifyFilters.Size | NotifyFilters.CreationTime;
+                combined.NotifyFilter = NotifyFilters.LastWrite | NotifyFilters.DirectoryName | NotifyFilters.FileName;
                 combined.IncludeSubdirectories = true;
                 combined.Created += OnRepositoryChanged;
                 combined.Renamed += OnRepositoryChanged;
@@ -52,7 +52,7 @@ namespace SourceGit.Models
                 var wc = new FileSystemWatcher();
                 wc.Path = fullpath;
                 wc.Filter = "*";
-                wc.NotifyFilter = NotifyFilters.LastWrite | NotifyFilters.DirectoryName | NotifyFilters.FileName | NotifyFilters.Size | NotifyFilters.CreationTime;
+                wc.NotifyFilter = NotifyFilters.LastWrite | NotifyFilters.DirectoryName | NotifyFilters.FileName;
                 wc.IncludeSubdirectories = true;
                 wc.Created += OnWorkingCopyChanged;
                 wc.Renamed += OnWorkingCopyChanged;
@@ -302,6 +302,13 @@ namespace SourceGit.Models
             {
                 Interlocked.Exchange(ref _updateBranch, DateTime.Now.AddSeconds(.5).ToFileTime());
             }
+            else if (name.StartsWith("reftable/", StringComparison.Ordinal))
+            {
+                var desired = DateTime.Now.AddSeconds(.5).ToFileTime();
+                Interlocked.Exchange(ref _updateBranch, desired);
+                Interlocked.Exchange(ref _updateTags, desired);
+                Interlocked.Exchange(ref _updateStashes, desired);
+            }
             else if (name.StartsWith("objects/", StringComparison.Ordinal) || name.Equals("index", StringComparison.Ordinal))
             {
                 Interlocked.Exchange(ref _updateWC, DateTime.Now.AddSeconds(1).ToFileTime());
