@@ -33,6 +33,40 @@ namespace SourceGit.Native
             }
         }
 
+        public string GetDataDir()
+        {
+            // AppImage supports portable mode
+            var appImage = Environment.GetEnvironmentVariable("APPIMAGE");
+            if (!string.IsNullOrEmpty(appImage) && File.Exists(appImage))
+            {
+                var portableDir = Path.Combine(Path.GetDirectoryName(appImage)!, "data");
+                if (Directory.Exists(portableDir))
+                    return portableDir;
+            }
+
+            // Runtime data dir: ~/.sourcegit
+            var home = Environment.GetFolderPath(Environment.SpecialFolder.UserProfile);
+            var dataDir = Path.Combine(home, ".sourcegit");
+            if (Directory.Exists(dataDir))
+                return dataDir;
+
+            // Migrate old data: ~/.config/SourceGit
+            var oldDataDir = Path.Combine(home, ".config", "SourceGit");
+            if (Directory.Exists(oldDataDir))
+            {
+                try
+                {
+                    Directory.Move(oldDataDir, dataDir);
+                }
+                catch
+                {
+                    // Ignore errors
+                }
+            }
+
+            return dataDir;
+        }
+
         public string FindGitExecutable()
         {
             return FindExecutable("git");
@@ -54,7 +88,6 @@ namespace SourceGit.Native
             finder.VSCodeInsiders(() => FindExecutable("code-insiders"));
             finder.VSCodium(() => FindExecutable("codium"));
             finder.Cursor(() => FindExecutable("cursor"));
-            finder.Fleet(() => FindJetBrainsFleet(localAppDataDir));
             finder.FindJetBrainsFromToolbox(() => Path.Combine(localAppDataDir, "JetBrains/Toolbox"));
             finder.SublimeText(() => FindExecutable("subl"));
             finder.Zed(() =>
@@ -135,11 +168,5 @@ namespace SourceGit.Native
             var local = Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.UserProfile), ".local", "bin", filename);
             return File.Exists(local) ? local : string.Empty;
         }
-
-        private string FindJetBrainsFleet(string localAppDataDir)
-        {
-            var path = Path.Combine(localAppDataDir, "JetBrains/Toolbox/apps/fleet/bin/Fleet");
-            return File.Exists(path) ? path : FindExecutable("fleet");
-        }
     }
 }
