@@ -114,6 +114,18 @@ namespace SourceGit.Native
             });
         }
 
+        public string GetDataDir()
+        {
+            var execFile = Process.GetCurrentProcess().MainModule!.FileName;
+            var portableDir = Path.Combine(Path.GetDirectoryName(execFile)!, "data");
+            if (Directory.Exists(portableDir))
+                return portableDir;
+
+            return Path.Combine(
+                Environment.GetFolderPath(Environment.SpecialFolder.ApplicationData),
+                "SourceGit");
+        }
+
         public string FindGitExecutable()
         {
             var reg = Microsoft.Win32.RegistryKey.OpenBaseKey(
@@ -188,7 +200,6 @@ namespace SourceGit.Native
             finder.VSCodeInsiders(FindVSCodeInsiders);
             finder.VSCodium(FindVSCodium);
             finder.Cursor(() => Path.Combine(localAppDataDir, @"Programs\Cursor\Cursor.exe"));
-            finder.Fleet(() => Path.Combine(localAppDataDir, @"Programs\Fleet\Fleet.exe"));
             finder.FindJetBrainsFromToolbox(() => Path.Combine(localAppDataDir, @"JetBrains\Toolbox"));
             finder.SublimeText(FindSublimeText);
             finder.Zed(FindZed);
@@ -402,7 +413,7 @@ namespace SourceGit.Native
                     {
                         var exec = instance.ProductPath;
                         var icon = instance.IsPrerelease ? "vs-preview" : "vs";
-                        finder.TryAdd(instance.DisplayName, icon, () => exec, GenerateCommandlineArgsForVisualStudio);
+                        finder.TryAdd(instance.DisplayName, icon, () => exec, GenerateVSProjectLaunchOptions);
                     }
                 }
             }
@@ -445,39 +456,20 @@ namespace SourceGit.Native
             }
         }
 
-        private string GenerateCommandlineArgsForVisualStudio(string path)
+        private List<Models.ExternalTool.LaunchOption> GenerateVSProjectLaunchOptions(string path)
         {
-            if (Directory.Exists(path))
-            {
-                var sln = FindVSSolutionFile(new DirectoryInfo(path), 4);
-                return string.IsNullOrEmpty(sln) ? path.Quoted() : sln.Quoted();
-            }
-
-            return path.Quoted();
-        }
-
-        private string FindVSSolutionFile(DirectoryInfo dir, int leftDepth)
-        {
-            var files = dir.GetFiles();
-            foreach (var f in files)
-            {
-                if (f.Name.EndsWith(".slnx", StringComparison.OrdinalIgnoreCase) ||
-                    f.Name.EndsWith(".sln", StringComparison.OrdinalIgnoreCase))
-                    return f.FullName;
-            }
-
-            if (leftDepth <= 0)
+            var root = new DirectoryInfo(path);
+            if (!root.Exists)
                 return null;
 
-            var subDirs = dir.GetDirectories();
-            foreach (var subDir in subDirs)
+            var options = new List<Models.ExternalTool.LaunchOption>();
+            root.WalkFiles(f =>
             {
-                var first = FindVSSolutionFile(subDir, leftDepth - 1);
-                if (!string.IsNullOrEmpty(first))
-                    return first;
-            }
-
-            return null;
+                if (f.EndsWith(".sln", StringComparison.OrdinalIgnoreCase) ||
+                    f.EndsWith(".slnx", StringComparison.OrdinalIgnoreCase))
+                    options.Add(new(root.GetRelativePath(f), f.Quoted()));
+            });
+            return options;
         }
     }
 }
