@@ -22,6 +22,11 @@ namespace SourceGit.ViewModels
             DiscardLocalChanges = false;
         }
 
+        public override bool CanStartDirectly()
+        {
+            return _repo.LocalChangesCount == 0;
+        }
+
         public override async Task<bool> Sure()
         {
             using var lockWatcher = _repo.LockWatcher();
@@ -52,7 +57,7 @@ namespace SourceGit.ViewModels
                 {
                     succ = await new Commands.Stash(_repo.FullPath)
                         .Use(log)
-                        .PushAsync("CHECKOUT_AUTO_STASH");
+                        .PushAsync("CHECKOUT_AUTO_STASH", false);
                     if (!succ)
                     {
                         log.Complete();
@@ -69,11 +74,7 @@ namespace SourceGit.ViewModels
 
             if (succ)
             {
-                var submodules = await new Commands.QueryUpdatableSubmodules(_repo.FullPath, false).GetResultAsync();
-                if (submodules.Count > 0)
-                    await new Commands.Submodule(_repo.FullPath)
-                        .Use(log)
-                        .UpdateAsync(submodules, false, true);
+                await _repo.AutoUpdateSubmodulesAsync(log);
 
                 if (needPopStash)
                     await new Commands.Stash(_repo.FullPath)
