@@ -57,7 +57,7 @@ namespace SourceGit.ViewModels
                 {
                     succ = await new Commands.Stash(_repo.FullPath)
                         .Use(log)
-                        .PushAsync("CHECKOUT_AND_FASTFORWARD_AUTO_STASH");
+                        .PushAsync("CHECKOUT_AND_FASTFORWARD_AUTO_STASH", false);
                     if (!succ)
                     {
                         log.Complete();
@@ -74,11 +74,7 @@ namespace SourceGit.ViewModels
 
             if (succ)
             {
-                var submodules = await new Commands.QueryUpdatableSubmodules(_repo.FullPath, false).GetResultAsync();
-                if (submodules.Count > 0)
-                    await new Commands.Submodule(_repo.FullPath)
-                        .Use(log)
-                        .UpdateAsync(submodules, false, true);
+                await _repo.AutoUpdateSubmodulesAsync(log);
 
                 if (needPopStash)
                     await new Commands.Stash(_repo.FullPath)
