@@ -52,7 +52,7 @@ namespace SourceGit.ViewModels
                 {
                     succ = await new Commands.Stash(_repo.FullPath)
                         .Use(log)
-                        .PushAsync("CHECKOUT_AUTO_STASH");
+                        .PushAsync("CHECKOUT_AUTO_STASH", false);
                     if (!succ)
                     {
                         log.Complete();
@@ -69,11 +69,7 @@ namespace SourceGit.ViewModels
 
             if (succ)
             {
-                var submodules = await new Commands.QueryUpdatableSubmodules(_repo.FullPath, false).GetResultAsync();
-                if (submodules.Count > 0)
-                    await new Commands.Submodule(_repo.FullPath)
-                        .Use(log)
-                        .UpdateAsync(submodules, false, true);
+                await _repo.AutoUpdateSubmodulesAsync(log);
 
                 if (needPop)
                     await new Commands.Stash(_repo.FullPath)
