@@ -1,4 +1,4 @@
-﻿using System;
+using System;
 using System.Collections.Generic;
 using System.IO;
 using System.Text.RegularExpressions;
@@ -7,7 +7,6 @@ using System.Threading.Tasks;
 
 using Avalonia;
 using Avalonia.Threading;
-
 using CommunityToolkit.Mvvm.ComponentModel;
 
 namespace SourceGit.ViewModels
@@ -249,53 +248,166 @@ namespace SourceGit.ViewModels
 
         public async Task ResetToThisRevisionAsync(string path)
         {
+            var c = _changes?.Find(x => x.Path.Equals(path, StringComparison.Ordinal));
+            if (c != null)
+            {
+                await ResetToThisRevisionAsync(c);
+                return;
+            }
+
             var log = _repo.CreateLog($"Reset File to '{_commit.SHA}'");
             await new Commands.Checkout(_repo.FullPath).Use(log).FileWithRevisionAsync(path, _commit.SHA);
             log.Complete();
         }
 
+        public async Task ResetToThisRevisionAsync(Models.Change change)
+        {
+            var log = _repo.CreateLog($"Reset File to '{_commit.SHA}'");
+
+            if (change.Index == Models.ChangeState.Deleted)
+            {
+                var fullpath = Native.OS.GetAbsPath(_repo.FullPath, change.Path);
+                if (File.Exists(fullpath))
+                    await new Commands.Remove(_repo.FullPath, [change.Path])
+                        .Use(log)
+                        .ExecAsync();
+            }
+            else if (change.Index == Models.ChangeState.Renamed)
+            {
+                var old = Native.OS.GetAbsPath(_repo.FullPath, change.OriginalPath);
+                if (File.Exists(old))
+                    await new Commands.Remove(_repo.FullPath, [change.OriginalPath])
+                        .Use(log)
+                        .ExecAsync();
+
+                await new Commands.Checkout(_repo.FullPath)
+                    .Use(log)
+                    .FileWithRevisionAsync(change.Path, _commit.SHA);
+            }
+            else
+            {
+                await new Commands.Checkout(_repo.FullPath)
+                    .Use(log)
+                    .FileWithRevisionAsync(change.Path, _commit.SHA);
+            }
+
+            log.Complete();
+        }
+
         public async Task ResetToParentRevisionAsync(Models.Change change)
         {
             var log = _repo.CreateLog($"Reset File to '{_commit.SHA}~1'");
 
-            if (change.Index == Models.ChangeState.Renamed)
-                await new Commands.Checkout(_repo.FullPath).Use(log).FileWithRevisionAsync(change.OriginalPath, $"{_commit.SHA}~1");
+            if (change.Index == Models.ChangeState.Added)
+            {
+                var fullpath = Native.OS.GetAbsPath(_repo.FullPath, change.Path);
+                if (File.Exists(fullpath))
+                    await new Commands.Remove(_repo.FullPath, [change.Path])
+                        .Use(log)
+                        .ExecAsync();
+            }
+            else if (change.Index == Models.ChangeState.Renamed)
+            {
+                var renamed = Native.OS.GetAbsPath(_repo.FullPath, change.Path);
+                if (File.Exists(renamed))
+                    await new Commands.Remove(_repo.FullPath, [change.Path])
+                        .Use(log)
+                        .ExecAsync();
+
+                await new Commands.Checkout(_repo.FullPath)
+                    .Use(log)
+                    .FileWithRevisionAsync(change.OriginalPath, $"{_commit.SHA}~1");
+            }
+            else
+            {
+                await new Commands.Checkout(_repo.FullPath)
+                    .Use(log)
+                    .FileWithRevisionAsync(change.Path, $"{_commit.SHA}~1");
+            }
 
-            await new Commands.Checkout(_repo.FullPath).Use(log).FileWithRevisionAsync(change.Path, $"{_commit.SHA}~1");
             log.Complete();
         }
 
         public async Task ResetMultipleToThisRevisionAsync(List<Models.Change> changes)
         {
-            var files = new List<string>();
+            var checkouts = new List<string>();
+            var removes = new List<string>();
+
             foreach (var c in changes)
-                files.Add(c.Path);
+            {
+                if (c.Index == Models.ChangeState.Deleted)
+                {
+                    var fullpath = Native.OS.GetAbsPath(_repo.FullPath, c.Path);
+                    if (File.Exists(fullpath))
+                        removes.Add(c.Path);
+                }
+                else if (c.Index == Models.ChangeState.Renamed)
+                {
+                    var old = Native.OS.GetAbsPath(_repo.FullPath, c.OriginalPath);
+                    if (File.Exists(old))
+                        removes.Add(c.OriginalPath);
+
+                    checkouts.Add(c.Path);
+                }
+                else
+                {
+                    checkouts.Add(c.Path);
+                }
+            }
 
             var log = _repo.CreateLog($"Reset Files to '{_commit.SHA}'");
-            await new Commands.Checkout(_repo.FullPath).Use(log).MultipleFilesWithRevisionAsync(files, _commit.SHA);
+
+            if (removes.Count > 0)
+                await new Commands.Remove(_repo.FullPath, removes)
+                    .Use(log)
+                    .ExecAsync();
+
+            if (checkouts.Count > 0)
+                await new Commands.Checkout(_repo.FullPath)
+                    .Use(log)
+                    .MultipleFilesWithRevisionAsync(checkouts, _commit.SHA);
+
             log.Complete();
         }
 
         public async Task ResetMultipleToParentRevisionAsync(List<Models.Change> changes)
         {
-            var renamed = new List<string>();
-            var modified = new List<string>();
+            var checkouts = new List<string>();
+            var removes = new List<string>();
 
             foreach (var c in changes)
             {
-                if (c.Index == Models.ChangeState.Renamed)
-                    renamed.Add(c.OriginalPath);
+                if (c.Index == Models.ChangeState.Added)
+                {
+                    var fullpath = Native.OS.GetAbsPath(_repo.FullPath, c.Path);
+                    if (File.Exists(fullpath))
+                        removes.Add(c.Path);
+                }
+                else if (c.Index == Models.ChangeState.Renamed)
+                {
+                    var renamed = Native.OS.GetAbsPath(_repo.FullPath, c.Path);
+                    if (File.Exists(renamed))
+                        removes.Add(c.Path);
+
+                    checkouts.Add(c.OriginalPath);
+                }
                 else
-                    modified.Add(c.Path);
+                {
+                    checkouts.Add(c.Path);
+                }
             }
 
             var log = _repo.CreateLog($"Reset Files to '{_commit.SHA}~1'");
 
-            if (modified.Count > 0)
-                await new Commands.Checkout(_repo.FullPath).Use(log).MultipleFilesWithRevisionAsync(modified, $"{_commit.SHA}~1");
+            if (removes.Count > 0)
+                await new Commands.Remove(_repo.FullPath, removes)
+                    .Use(log)
+                    .ExecAsync();
 
-            if (renamed.Count > 0)
-                await new Commands.Checkout(_repo.FullPath).Use(log).MultipleFilesWithRevisionAsync(renamed, $"{_commit.SHA}~1");
+            if (checkouts.Count > 0)
+                await new Commands.Checkout(_repo.FullPath)
+                    .Use(log)
+                    .MultipleFilesWithRevisionAsync(checkouts, $"{_commit.SHA}~1");
 
             log.Complete();
         }
@@ -343,7 +455,7 @@ namespace SourceGit.ViewModels
             if (tool == null)
                 Native.OS.OpenWithDefaultEditor(tmpFile);
             else
-                tool.Open(tmpFile);
+                tool.Launch(tmpFile.Quoted());
         }
 
         public async Task SaveRevisionFileAsync(Models.Object file, string saveTo)
@@ -485,6 +597,17 @@ namespace SourceGit.ViewModels
                     inlines.Add(new Models.InlineElement(Models.InlineElementType.CommitSHA, start, len, sha));
             }
 
+            var inlineCodeMatches = REG_INLINECODE_FORMAT().Matches(message);
+            foreach (Match match in inlineCodeMatches)
+            {
+                var start = match.Index;
+                var len = match.Length;
+                if (inlines.Intersect(start, len) != null)
+                    continue;
+
+                inlines.Add(new Models.InlineElement(Models.InlineElementType.Code, start + 1, len - 2, string.Empty));
+            }
+
             inlines.Sort();
             return inlines;
         }
@@ -633,6 +756,9 @@ namespace SourceGit.ViewModels
         [GeneratedRegex(@"\b([0-9a-fA-F]{6,40})\b")]
         private static partial Regex REG_SHA_FORMAT();
 
+        [GeneratedRegex(@"`.*?`")]
+        private static partial Regex REG_INLINECODE_FORMAT();
+
         private Repository _repo = null;
         private CommitDetailSharedData _sharedData = null;
         private Models.Commit _commit = null;
