@@ -28,12 +28,12 @@ namespace SourceGit.ViewModels
 
         public bool CheckoutAfterCreated
         {
-            get => _repo.Settings.CheckoutBranchOnCreateBranch;
+            get => _repo.UIStates.CheckoutBranchOnCreateBranch;
             set
             {
-                if (_repo.Settings.CheckoutBranchOnCreateBranch != value)
+                if (_repo.UIStates.CheckoutBranchOnCreateBranch != value)
                 {
-                    _repo.Settings.CheckoutBranchOnCreateBranch = value;
+                    _repo.UIStates.CheckoutBranchOnCreateBranch = value;
                     OnPropertyChanged();
                 }
             }
@@ -54,23 +54,12 @@ namespace SourceGit.ViewModels
             }
         }
 
-        public bool IsRecurseSubmoduleVisible
-        {
-            get => _repo.Submodules.Count > 0;
-        }
-
-        public bool RecurseSubmodules
-        {
-            get => _repo.Settings.UpdateSubmodulesOnCheckoutBranch;
-            set => _repo.Settings.UpdateSubmodulesOnCheckoutBranch = value;
-        }
-
         public CreateBranch(Repository repo, Models.Branch branch)
         {
             _repo = repo;
             _baseOnRevision = branch.Head;
 
-            if (!branch.IsLocal && repo.Branches.Find(x => x.IsLocal && x.Name == branch.Name) == null)
+            if (!branch.IsLocal)
                 Name = branch.Name;
 
             BasedOn = branch;
@@ -147,7 +136,7 @@ namespace SourceGit.ViewModels
                     {
                         succ = await new Commands.Stash(_repo.FullPath)
                             .Use(log)
-                            .PushAsync("CREATE_BRANCH_AUTO_STASH");
+                            .PushAsync("CREATE_BRANCH_AUTO_STASH", false);
                         if (!succ)
                         {
                             log.Complete();
@@ -164,14 +153,7 @@ namespace SourceGit.ViewModels
 
                 if (succ)
                 {
-                    if (IsRecurseSubmoduleVisible && RecurseSubmodules)
-                    {
-                        var submodules = await new Commands.QueryUpdatableSubmodules(_repo.FullPath).GetResultAsync();
-                        if (submodules.Count > 0)
-                            await new Commands.Submodule(_repo.FullPath)
-                                .Use(log)
-                                .UpdateAsync(submodules, true, true);
-                    }
+                    await _repo.AutoUpdateSubmodulesAsync(log);
 
                     if (needPopStash)
                         await new Commands.Stash(_repo.FullPath)
@@ -203,7 +185,7 @@ namespace SourceGit.ViewModels
 
                 var folderEndIdx = fake.FullName.LastIndexOf('/');
                 if (folderEndIdx > 10)
-                    _repo.Settings.ExpandedBranchNodesInSideBar.Add(fake.FullName.Substring(0, folderEndIdx));
+                    _repo.UIStates.ExpandedBranchNodesInSideBar.Add(fake.FullName.Substring(0, folderEndIdx));
 
                 if (_repo.HistoryFilterMode == Models.FilterMode.Included)
                     _repo.SetBranchFilterMode(fake, Models.FilterMode.Included, false, false);
