@@ -104,6 +104,12 @@ namespace SourceGit.ViewModels
             set => SetProperty(ref _editorTabWidth, value);
         }
 
+        public double Zoom
+        {
+            get => _zoom;
+            set => SetProperty(ref _zoom, value);
+        }
+
         public LayoutInfo Layout
         {
             get => _layout;
@@ -191,24 +197,12 @@ namespace SourceGit.ViewModels
             set => SetProperty(ref _ignoreUpdateTag, value);
         }
 
-        public bool ShowTagsAsTree
-        {
-            get;
-            set;
-        } = false;
-
         public bool ShowTagsInGraph
         {
             get => _showTagsInGraph;
             set => SetProperty(ref _showTagsInGraph, value);
         }
 
-        public bool ShowSubmodulesAsTree
-        {
-            get;
-            set;
-        } = false;
-
         public bool UseTwoColumnsLayoutInHistories
         {
             get => _useTwoColumnsLayoutInHistories;
@@ -770,6 +764,7 @@ namespace SourceGit.ViewModels
         private double _defaultFontSize = 13;
         private double _editorFontSize = 13;
         private int _editorTabWidth = 4;
+        private double _zoom = 1.0;
         private LayoutInfo _layout = new();
 
         private int _maxHistoryCommits = 20000;
