@@ -46,8 +46,8 @@ namespace SourceGit.ViewModels
 
         public bool UseRebase
         {
-            get => _repo.Settings.PreferRebaseInsteadOfMerge;
-            set => _repo.Settings.PreferRebaseInsteadOfMerge = value;
+            get => _repo.UIStates.PreferRebaseInsteadOfMerge;
+            set => _repo.UIStates.PreferRebaseInsteadOfMerge = value;
         }
 
         public Pull(Repository repo, Models.Branch specifiedRemoteBranch)
@@ -117,7 +117,7 @@ namespace SourceGit.ViewModels
                 }
                 else
                 {
-                    var succ = await new Commands.Stash(_repo.FullPath).Use(log).PushAsync("PULL_AUTO_STASH");
+                    var succ = await new Commands.Stash(_repo.FullPath).Use(log).PushAsync("PULL_AUTO_STASH", false);
                     if (!succ)
                     {
                         log.Complete();
@@ -135,9 +135,7 @@ namespace SourceGit.ViewModels
                 UseRebase).Use(log).RunAsync();
             if (rs)
             {
-                var submodules = await new Commands.QueryUpdatableSubmodules(_repo.FullPath, false).GetResultAsync();
-                if (submodules.Count > 0)
-                    await new Commands.Submodule(_repo.FullPath).Use(log).UpdateAsync(submodules, false, true);
+                await _repo.AutoUpdateSubmodulesAsync(log);
 
                 if (needPopStash)
                     await new Commands.Stash(_repo.FullPath).Use(log).PopAsync("stash@{0}");
