@@ -60,17 +60,7 @@ namespace SourceGit.ViewModels
                 .RenameAsync(_name);
 
             if (succ)
-            {
-                foreach (var filter in _repo.HistoryFilterCollection.Filters)
-                {
-                    if (filter.Type == Models.FilterType.LocalBranch &&
-                        filter.Pattern.Equals(oldName, StringComparison.Ordinal))
-                    {
-                        filter.Pattern = $"refs/heads/{_name}";
-                        break;
-                    }
-                }
-            }
+                _repo.UIStates.RenameBranchFilter(Target.FullName, _name);
 
             log.Complete();
             _repo.MarkBranchesDirtyManually();
