@@ -95,6 +95,12 @@ namespace SourceGit.ViewModels
             set;
         }
 
+        public bool AskBeforeAutoUpdatingSubmodules
+        {
+            get => _repo.Settings.AskBeforeAutoUpdatingSubmodules;
+            set => _repo.Settings.AskBeforeAutoUpdatingSubmodules = value;
+        }
+
         public bool EnableAutoFetch
         {
             get => _repo.Settings.EnableAutoFetch;
@@ -289,6 +295,7 @@ namespace SourceGit.ViewModels
             await SetIfChangedAsync("fetch.prune", EnablePruneOnFetch ? "true" : "false", "false");
 
             await ApplyIssueTrackerChangesAsync();
+            await _repo.Settings.SaveAsync();
         }
 
         private async Task SetIfChangedAsync(string key, string value, string defValue)
@@ -353,8 +360,8 @@ namespace SourceGit.ViewModels
             }
         }
 
-        private readonly Repository _repo = null;
-        private readonly Dictionary<string, string> _cached = null;
+        private readonly Repository _repo;
+        private readonly Dictionary<string, string> _cached;
         private string _httpProxy;
         private Models.CommitTemplate _selectedCommitTemplate = null;
         private Models.IssueTracker _selectedIssueTracker = null;
