@@ -38,8 +38,8 @@ namespace SourceGit.ViewModels
             Use(log);
 
             var changes = await new Commands.QueryLocalChanges(_repo.FullPath, false).GetResultAsync();
-            var signOff = _repo.Settings.EnableSignOffForCommit;
-            var noVerify = _repo.Settings.NoVerifyOnCommit;
+            var signOff = _repo.UIStates.EnableSignOffForCommit;
+            var noVerify = _repo.UIStates.NoVerifyOnCommit;
             var needAutoStash = false;
             var succ = false;
 
@@ -56,7 +56,7 @@ namespace SourceGit.ViewModels
             {
                 succ = await new Commands.Stash(_repo.FullPath)
                     .Use(log)
-                    .PushAsync("REWORD_AUTO_STASH");
+                    .PushAsync("REWORD_AUTO_STASH", false);
                 if (!succ)
                 {
                     log.Complete();
