@@ -1,4 +1,6 @@
+using System;
 using System.Reflection;
+
 using Avalonia.Interactivity;
 
 namespace SourceGit.Views
@@ -15,6 +17,16 @@ namespace SourceGit.Views
             if (ver != null)
                 TxtVersion.Text = $"{ver.Major}.{ver.Minor:D2}";
 
+            var meta = assembly.GetCustomAttributes<AssemblyMetadataAttribute>();
+            foreach (var attr in meta)
+            {
+                if (attr.Key.Equals("BuildDate", StringComparison.OrdinalIgnoreCase) && DateTime.TryParse(attr.Value, out var date))
+                {
+                    TxtReleaseDate.Text = App.Text("About.ReleaseDate", date.ToLocalTime().ToString("MMM d yyyy"));
+                    break;
+                }
+            }
+
             var copyright = assembly.GetCustomAttribute<AssemblyCopyrightAttribute>();
             if (copyright != null)
                 TxtCopyright.Text = copyright.Copyright;
