@@ -8,6 +8,15 @@ namespace SourceGit.Views
 {
     public class ChromelessWindow : Window
     {
+        public static readonly StyledProperty<double> LeftCaptionButtonWidthProperty =
+            AvaloniaProperty.Register<ChromelessWindow, double>(nameof(LeftCaptionButtonWidth), 72.0);
+
+        public double LeftCaptionButtonWidth
+        {
+            get => GetValue(LeftCaptionButtonWidthProperty);
+            set => SetValue(LeftCaptionButtonWidthProperty, value);
+        }
+
         public bool UseSystemWindowFrame
         {
             get => Native.OS.UseSystemWindowFrame;
@@ -23,6 +32,7 @@ namespace SourceGit.Views
 
         public ChromelessWindow()
         {
+            LeftCaptionButtonWidth = 72.0 / Math.Max(1.0, ViewModels.Preferences.Instance.Zoom);
             Focusable = true;
             Native.OS.SetupForWindow(this);
         }
@@ -97,10 +107,32 @@ namespace SourceGit.Views
         {
             base.OnKeyDown(e);
 
-            if (e is { Handled: false, Key: Key.Escape, KeyModifiers: KeyModifiers.None } && CloseOnESC)
+            if (e.Handled)
+                return;
+
+            if (e is { Key: Key.Escape, KeyModifiers: KeyModifiers.None } && CloseOnESC)
             {
                 Close();
                 e.Handled = true;
+                return;
+            }
+
+            if (e.KeyModifiers == (OperatingSystem.IsMacOS() ? KeyModifiers.Meta : KeyModifiers.Control))
+            {
+                if (e.Key == Key.OemPlus)
+                {
+                    var zoom = Math.Min(ViewModels.Preferences.Instance.Zoom + 0.05, 2.5);
+                    ViewModels.Preferences.Instance.Zoom = zoom;
+                    LeftCaptionButtonWidth = 72.0 / zoom;
+                    e.Handled = true;
+                }
+                else if (e.Key == Key.OemMinus)
+                {
+                    var zoom = Math.Max(ViewModels.Preferences.Instance.Zoom - 0.05, 1);
+                    ViewModels.Preferences.Instance.Zoom = zoom;
+                    LeftCaptionButtonWidth = 72.0 / zoom;
+                    e.Handled = true;
+                }
             }
         }
 
