@@ -44,7 +44,7 @@ namespace SourceGit.Views
 
             var patch = new MenuItem();
             patch.Header = App.Text("FileCM.SaveAsPatch");
-            patch.Icon = App.CreateMenuIcon("Icons.Diff");
+            patch.Icon = App.CreateMenuIcon("Icons.Save");
             patch.Click += async (_, e) =>
             {
                 var storageProvider = TopLevel.GetTopLevel(this)?.StorageProvider;
@@ -112,7 +112,7 @@ namespace SourceGit.Views
 
             var patch = new MenuItem();
             patch.Header = App.Text("FileCM.SaveAsPatch");
-            patch.Icon = App.CreateMenuIcon("Icons.Diff");
+            patch.Icon = App.CreateMenuIcon("Icons.Save");
             patch.Click += async (_, e) =>
             {
                 var storageProvider = TopLevel.GetTopLevel(this)?.StorageProvider;
@@ -289,7 +289,7 @@ namespace SourceGit.Views
 
             var patch = new MenuItem();
             patch.Header = App.Text("FileCM.SaveAsPatch");
-            patch.Icon = App.CreateMenuIcon("Icons.Diff");
+            patch.Icon = App.CreateMenuIcon("Icons.Save");
             patch.Click += async (_, e) =>
             {
                 var storageProvider = TopLevel.GetTopLevel(this)?.StorageProvider;
@@ -335,7 +335,7 @@ namespace SourceGit.Views
                 resetToThisRevision.Icon = App.CreateMenuIcon("Icons.File.Checkout");
                 resetToThisRevision.Click += async (_, ev) =>
                 {
-                    await vm.ResetToThisRevisionAsync(change.Path);
+                    await vm.ResetToThisRevisionAsync(change);
                     ev.Handled = true;
                 };
 
