@@ -8,6 +8,7 @@ using Avalonia.Controls;
 using Avalonia.Controls.Primitives;
 using Avalonia.Input;
 using Avalonia.Interactivity;
+using Avalonia.Media;
 using Avalonia.Platform.Storage;
 using Avalonia.VisualTree;
 
@@ -158,6 +159,52 @@ namespace SourceGit.Views
                 dataGrid.ScrollIntoView(dataGrid.SelectedItem, null);
         }
 
+        private async void OnGotoParent(object sender, RoutedEventArgs e)
+        {
+            if (DataContext is not ViewModels.Histories vm)
+                return;
+
+            if (!CommitListContainer.IsKeyboardFocusWithin)
+                return;
+
+            if (CommitListContainer.SelectedItems is not { Count: 1 } selected)
+                return;
+
+            if (selected[0] is not Models.Commit { Parents.Count: > 0 } commit)
+                return;
+
+            if (commit.Parents.Count == 1)
+            {
+                vm.NavigateTo(commit.Parents[0]);
+                e.Handled = true;
+                return;
+            }
+
+            var parents = new List<Models.Commit>();
+            foreach (var sha in commit.Parents)
+            {
+                var c = await vm.GetCommitAsync(sha);
+                if (c != null)
+                    parents.Add(c);
+            }
+
+            if (parents.Count == 1)
+            {
+                vm.NavigateTo(parents[0].SHA);
+            }
+            else if (parents.Count > 1 && TopLevel.GetTopLevel(this) is Window owner)
+            {
+                var dialog = new GotoParentSelector();
+                dialog.ParentList.ItemsSource = parents;
+
+                var c = await dialog.ShowDialog<Models.Commit>(owner);
+                if (c != null)
+                    vm.NavigateTo(c.SHA);
+            }
+
+            e.Handled = true;
+        }
+
         private void OnCommitListLayoutUpdated(object _1, EventArgs _2)
         {
             if (!IsLoaded)
@@ -216,13 +263,16 @@ namespace SourceGit.Views
 
         private void OnCommitListContextRequested(object sender, ContextRequestedEventArgs e)
         {
-            if (sender is DataGrid { SelectedItems: { } selected } dataGrid &&
-                e.Source is Control { DataContext: Models.Commit })
+            if (e.Source is Control { DataContext: Models.Commit })
             {
                 var repoView = this.FindAncestorOfType<Repository>();
                 if (repoView is not { DataContext: ViewModels.Repository repo })
                     return;
 
+                var selected = CommitListContainer.SelectedItems;
+                if (selected is not { Count: > 0 })
+                    return;
+
                 var commits = new List<Models.Commit>();
                 for (var i = selected.Count - 1; i >= 0; i--)
                 {
@@ -233,14 +283,64 @@ namespace SourceGit.Views
                 if (selected.Count > 1)
                 {
                     var menu = CreateContextMenuForMultipleCommits(repo, commits);
-                    menu.Open(dataGrid);
+                    menu.Open(CommitListContainer);
                 }
                 else if (selected.Count == 1)
                 {
                     var menu = CreateContextMenuForSingleCommit(repo, commits[0]);
-                    menu.Open(dataGrid);
+                    menu.Open(CommitListContainer);
                 }
             }
+            else if (e.Source is Control elem)
+            {
+                var headersPresenter = CommitListContainer.FindDescendantOfType<DataGridColumnHeadersPresenter>();
+                if (!headersPresenter.IsVisualAncestorOf(elem))
+                    return;
+
+                if (DataContext is not ViewModels.Histories vm)
+                    return;
+
+                var columnsHeader = new MenuItem();
+                columnsHeader.Header = new TextBlock() { Text = App.Text("Histories.ShowColumns"), FontWeight = FontWeight.Bold };
+                columnsHeader.IsEnabled = false;
+
+                var authorColumn = new MenuItem();
+                authorColumn.Header = App.Text("Histories.Header.Author");
+                if (vm.IsAuthorColumnVisible)
+                    authorColumn.Icon = App.CreateMenuIcon("Icons.Check");
+                authorColumn.Click += (_, ev) =>
+                {
+                    vm.IsAuthorColumnVisible = !vm.IsAuthorColumnVisible;
+                    ev.Handled = true;
+                };
+
+                var shaColumn = new MenuItem();
+                shaColumn.Header = App.Text("Histories.Header.SHA");
+                if (vm.IsSHAColumnVisible)
+                    shaColumn.Icon = App.CreateMenuIcon("Icons.Check");
+                shaColumn.Click += (_, ev) =>
+                {
+                    vm.IsSHAColumnVisible = !vm.IsSHAColumnVisible;
+                    ev.Handled = true;
+                };
+
+                var timeColumn = new MenuItem();
+                timeColumn.Header = App.Text("Histories.Header.DateTime");
+                if (vm.IsDateTimeColumnVisible)
+                    timeColumn.Icon = App.CreateMenuIcon("Icons.Check");
+                timeColumn.Click += (_, ev) =>
+                {
+                    vm.IsDateTimeColumnVisible = !vm.IsDateTimeColumnVisible;
+                    ev.Handled = true;
+                };
+
+                var menu = new ContextMenu();
+                menu.Items.Add(columnsHeader);
+                menu.Items.Add(authorColumn);
+                menu.Items.Add(shaColumn);
+                menu.Items.Add(timeColumn);
+                menu.Open(CommitListContainer);
+            }
 
             e.Handled = true;
         }
@@ -373,7 +473,7 @@ namespace SourceGit.Views
             }
 
             var saveToPatch = new MenuItem();
-            saveToPatch.Icon = App.CreateMenuIcon("Icons.Diff");
+            saveToPatch.Icon = App.CreateMenuIcon("Icons.Save");
             saveToPatch.Header = App.Text("CommitCM.SaveAsPatch");
             saveToPatch.Click += async (_, e) =>
             {
@@ -411,6 +511,19 @@ namespace SourceGit.Views
             menu.Items.Add(saveToPatch);
             menu.Items.Add(new MenuItem() { Header = "-" });
 
+            var copyInfos = new MenuItem();
+            copyInfos.Header = App.Text("CommitCM.CopySHA") + " - " + App.Text("CommitCM.CopySubject");
+            copyInfos.Tag = OperatingSystem.IsMacOS() ? "⌘+C" : "Ctrl+C";
+            copyInfos.Click += async (_, e) =>
+            {
+                var builder = new StringBuilder();
+                foreach (var c in selected)
+                    builder.Append(c.SHA.AsSpan(0, 10)).Append(" - ").AppendLine(c.Subject);
+
+                await App.CopyTextAsync(builder.ToString());
+                e.Handled = true;
+            };
+
             var copyShas = new MenuItem();
             copyShas.Header = App.Text("CommitCM.CopySHA");
             copyShas.Icon = App.CreateMenuIcon("Icons.Hash");
@@ -424,15 +537,14 @@ namespace SourceGit.Views
                 e.Handled = true;
             };
 
-            var copyInfos = new MenuItem();
-            copyInfos.Header = App.Text("CommitCM.CopySHA") + " - " + App.Text("CommitCM.CopySubject");
-            copyInfos.Icon = App.CreateMenuIcon("Icons.ShaAndSubject");
-            copyInfos.Tag = OperatingSystem.IsMacOS() ? "⌘+C" : "Ctrl+C";
-            copyInfos.Click += async (_, e) =>
+            var copySubjects = new MenuItem();
+            copySubjects.Header = App.Text("CommitCM.CopySubject");
+            copySubjects.Icon = App.CreateMenuIcon("Icons.Subject");
+            copySubjects.Click += async (_, e) =>
             {
                 var builder = new StringBuilder();
                 foreach (var c in selected)
-                    builder.Append(c.SHA.AsSpan(0, 10)).Append(" - ").AppendLine(c.Subject);
+                    builder.AppendLine(c.Subject);
 
                 await App.CopyTextAsync(builder.ToString());
                 e.Handled = true;
@@ -440,14 +552,14 @@ namespace SourceGit.Views
 
             var copyMessage = new MenuItem();
             copyMessage.Header = App.Text("CommitCM.CopyCommitMessage");
-            copyMessage.Icon = App.CreateMenuIcon("Icons.Info");
+            copyMessage.Icon = App.CreateMenuIcon("Icons.Message");
             copyMessage.Click += async (_, e) =>
             {
                 var vm = DataContext as ViewModels.Histories;
                 var messages = new List<string>();
                 foreach (var c in selected)
                 {
-                    var message = await vm.GetCommitFullMessageAsync(c);
+                    var message = await vm!.GetCommitFullMessageAsync(c);
                     messages.Add(message);
                 }
 
@@ -458,8 +570,10 @@ namespace SourceGit.Views
             var copy = new MenuItem();
             copy.Header = App.Text("Copy");
             copy.Icon = App.CreateMenuIcon("Icons.Copy");
-            copy.Items.Add(copyShas);
             copy.Items.Add(copyInfos);
+            copy.Items.Add(new MenuItem() { Header = "-" });
+            copy.Items.Add(copyShas);
+            copy.Items.Add(copySubjects);
             copy.Items.Add(copyMessage);
             menu.Items.Add(copy);
             return menu;
@@ -540,6 +654,8 @@ namespace SourceGit.Views
             if (!repo.IsBare)
             {
                 var target = commit.GetFriendlyName();
+                if (target.Length > 32)
+                    target = commit.SHA.Substring(0, 10);
 
                 if (isHead)
                 {
@@ -801,7 +917,7 @@ namespace SourceGit.Views
             }
 
             var saveToPatch = new MenuItem();
-            saveToPatch.Icon = App.CreateMenuIcon("Icons.Diff");
+            saveToPatch.Icon = App.CreateMenuIcon("Icons.Save");
             saveToPatch.Header = App.Text("CommitCM.SaveAsPatch");
             saveToPatch.Click += async (_, e) =>
             {
@@ -867,6 +983,15 @@ namespace SourceGit.Views
                 menu.Items.Add(new MenuItem() { Header = "-" });
             }
 
+            var copyInfo = new MenuItem();
+            copyInfo.Header = App.Text("CommitCM.CopySHA") + " - " + App.Text("CommitCM.CopySubject");
+            copyInfo.Tag = OperatingSystem.IsMacOS() ? "⌘+C" : "Ctrl+C";
+            copyInfo.Click += async (_, e) =>
+            {
+                await App.CopyTextAsync($"{commit.SHA.AsSpan(0, 10)} - {commit.Subject}");
+                e.Handled = true;
+            };
+
             var copySHA = new MenuItem();
             copySHA.Header = App.Text("CommitCM.CopySHA");
             copySHA.Icon = App.CreateMenuIcon("Icons.Hash");
@@ -885,19 +1010,9 @@ namespace SourceGit.Views
                 e.Handled = true;
             };
 
-            var copyInfo = new MenuItem();
-            copyInfo.Header = App.Text("CommitCM.CopySHA") + " - " + App.Text("CommitCM.CopySubject");
-            copyInfo.Icon = App.CreateMenuIcon("Icons.ShaAndSubject");
-            copyInfo.Tag = OperatingSystem.IsMacOS() ? "⌘+C" : "Ctrl+C";
-            copyInfo.Click += async (_, e) =>
-            {
-                await App.CopyTextAsync($"{commit.SHA.AsSpan(0, 10)} - {commit.Subject}");
-                e.Handled = true;
-            };
-
             var copyMessage = new MenuItem();
             copyMessage.Header = App.Text("CommitCM.CopyCommitMessage");
-            copyMessage.Icon = App.CreateMenuIcon("Icons.Info");
+            copyMessage.Icon = App.CreateMenuIcon("Icons.Message");
             copyMessage.Click += async (_, e) =>
             {
                 var message = await vm.GetCommitFullMessageAsync(commit);
@@ -926,9 +1041,10 @@ namespace SourceGit.Views
             var copy = new MenuItem();
             copy.Header = App.Text("Copy");
             copy.Icon = App.CreateMenuIcon("Icons.Copy");
+            copy.Items.Add(copyInfo);
+            copy.Items.Add(new MenuItem() { Header = "-" });
             copy.Items.Add(copySHA);
             copy.Items.Add(copySubject);
-            copy.Items.Add(copyInfo);
             copy.Items.Add(copyMessage);
             copy.Items.Add(copyAuthor);
             copy.Items.Add(copyCommitter);
