@@ -4,6 +4,7 @@ using Avalonia;
 using Avalonia.Controls;
 using Avalonia.Input;
 using Avalonia.Interactivity;
+using Avalonia.Markup.Xaml.MarkupExtensions;
 using Avalonia.Media;
 using Avalonia.Platform;
 using Avalonia.VisualTree;
@@ -61,6 +62,17 @@ namespace SourceGit.Views
             InitializeComponent();
             PositionChanged += OnPositionChanged;
 
+            if (OperatingSystem.IsWindows() && OperatingSystem.IsWindowsVersionAtLeast(10, 0, 22000))
+            {
+                Background = Brushes.Transparent;
+                TransparencyLevelHint = [WindowTransparencyLevel.Mica];
+                TitleBarBG.Background = Brushes.Transparent;
+            }
+            else
+            {
+                TitleBarBG.Bind(BackgroundProperty, new DynamicResourceExtension("Brush.TitleBar"));
+            }
+
             var layout = ViewModels.Preferences.Instance.Layout;
             Width = layout.LauncherWidth;
             Height = layout.LauncherHeight;
