@@ -62,12 +62,6 @@ namespace SourceGit.Views
             e.Handled = true;
         }
 
-        private void OnBranchTreeRowsChanged(object _, RoutedEventArgs e)
-        {
-            UpdateLeftSidebarLayout();
-            e.Handled = true;
-        }
-
         private void OnLocalBranchTreeSelectionChanged(object _1, RoutedEventArgs _2)
         {
             RemoteBranchTree.UnselectAll();
@@ -80,24 +74,12 @@ namespace SourceGit.Views
             TagsList.UnselectAll();
         }
 
-        private void OnTagsRowsChanged(object _, RoutedEventArgs e)
-        {
-            UpdateLeftSidebarLayout();
-            e.Handled = true;
-        }
-
         private void OnTagsSelectionChanged(object _1, RoutedEventArgs _2)
         {
             LocalBranchTree.UnselectAll();
             RemoteBranchTree.UnselectAll();
         }
 
-        private void OnSubmodulesRowsChanged(object _, RoutedEventArgs e)
-        {
-            UpdateLeftSidebarLayout();
-            e.Handled = true;
-        }
-
         private void OnWorktreeContextRequested(object sender, ContextRequestedEventArgs e)
         {
             if (sender is ListBox { SelectedItem: Models.Worktree worktree } grid && DataContext is ViewModels.Repository repo)
@@ -181,6 +163,12 @@ namespace SourceGit.Views
                 UpdateLeftSidebarLayout();
         }
 
+        private void OnLeftSidebarRowsChanged(object _, RoutedEventArgs e)
+        {
+            UpdateLeftSidebarLayout();
+            e.Handled = true;
+        }
+
         private void OnLeftSidebarSizeChanged(object _, SizeChangedEventArgs e)
         {
             if (e.HeightChanged)
@@ -419,22 +407,22 @@ namespace SourceGit.Views
                 var dateOrder = new MenuItem();
                 dateOrder.Header = App.Text("Repository.HistoriesOrder.ByDate");
                 dateOrder.Tag = "--date-order";
-                if (!repo.EnableTopoOrderInHistories)
+                if (!repo.EnableTopoOrderInHistory)
                     dateOrder.Icon = App.CreateMenuIcon("Icons.Check");
                 dateOrder.Click += (_, ev) =>
                 {
-                    repo.EnableTopoOrderInHistories = false;
+                    repo.EnableTopoOrderInHistory = false;
                     ev.Handled = true;
                 };
 
                 var topoOrder = new MenuItem();
                 topoOrder.Header = App.Text("Repository.HistoriesOrder.Topo");
                 topoOrder.Tag = "--topo-order";
-                if (repo.EnableTopoOrderInHistories)
+                if (repo.EnableTopoOrderInHistory)
                     topoOrder.Icon = App.CreateMenuIcon("Icons.Check");
                 topoOrder.Click += (_, ev) =>
                 {
-                    repo.EnableTopoOrderInHistories = true;
+                    repo.EnableTopoOrderInHistory = true;
                     ev.Handled = true;
                 };
 
@@ -585,6 +573,14 @@ namespace SourceGit.Views
             e.Handled = true;
         }
 
+        private void OnResolveInProgress(object sender, RoutedEventArgs e)
+        {
+            if (DataContext is ViewModels.Repository repo)
+                repo.SelectedViewIndex = 1;
+
+            e.Handled = true;
+        }
+
         private async void OnAbortInProgress(object sender, RoutedEventArgs e)
         {
             if (DataContext is ViewModels.Repository repo)
