@@ -613,19 +613,7 @@ namespace SourceGit.Views
                     ev.Handled = true;
                 };
 
-                var change = vm.Changes.Find(x => x.Path == file.Path) ?? new Models.Change() { Index = Models.ChangeState.None, Path = file.Path };
-                var resetToFirstParent = new MenuItem();
-                resetToFirstParent.Header = App.Text("ChangeCM.CheckoutFirstParentRevision");
-                resetToFirstParent.Icon = App.CreateMenuIcon("Icons.File.Checkout");
-                resetToFirstParent.IsEnabled = commit.Parents.Count > 0;
-                resetToFirstParent.Click += async (_, ev) =>
-                {
-                    await vm.ResetToParentRevisionAsync(change);
-                    ev.Handled = true;
-                };
-
                 menu.Items.Add(resetToThisRevision);
-                menu.Items.Add(resetToFirstParent);
                 menu.Items.Add(new MenuItem() { Header = "-" });
 
                 if (repo.Remotes.Count > 0 && File.Exists(fullPath) && repo.IsLFSEnabled())
@@ -641,7 +629,7 @@ namespace SourceGit.Views
                     {
                         lfsLock.Click += async (_, e) =>
                         {
-                            await repo.LockLFSFileAsync(repo.Remotes[0].Name, change.Path);
+                            await repo.LockLFSFileAsync(repo.Remotes[0].Name, file.Path);
                             e.Handled = true;
                         };
                     }
@@ -654,7 +642,7 @@ namespace SourceGit.Views
                             lockRemote.Header = remoteName;
                             lockRemote.Click += async (_, e) =>
                             {
-                                await repo.LockLFSFileAsync(remoteName, change.Path);
+                                await repo.LockLFSFileAsync(remoteName, file.Path);
                                 e.Handled = true;
                             };
                             lfsLock.Items.Add(lockRemote);
@@ -669,7 +657,7 @@ namespace SourceGit.Views
                     {
                         lfsUnlock.Click += async (_, e) =>
                         {
-                            await repo.UnlockLFSFileAsync(repo.Remotes[0].Name, change.Path, false, true);
+                            await repo.UnlockLFSFileAsync(repo.Remotes[0].Name, file.Path, false, true);
                             e.Handled = true;
                         };
                     }
@@ -682,7 +670,7 @@ namespace SourceGit.Views
                             unlockRemote.Header = remoteName;
                             unlockRemote.Click += async (_, e) =>
                             {
-                                await repo.UnlockLFSFileAsync(remoteName, change.Path, false, true);
+                                await repo.UnlockLFSFileAsync(remoteName, file.Path, false, true);
                                 e.Handled = true;
                             };
                             lfsUnlock.Items.Add(unlockRemote);
