@@ -79,7 +79,7 @@ namespace SourceGit.Views
             {
                 Width = 12,
                 Height = 12,
-                HorizontalAlignment = HorizontalAlignment.Left,
+                HorizontalAlignment = HorizontalAlignment.Center,
                 VerticalAlignment = VerticalAlignment.Center,
                 Margin = margin,
                 Data = geo,
@@ -257,6 +257,24 @@ namespace SourceGit.Views
                     ev.Handled = true;
                 };
 
+                var compareWithHead = new MenuItem();
+                compareWithHead.Header = App.Text("TagCM.CompareWithHead");
+                compareWithHead.Icon = App.CreateMenuIcon("Icons.Compare");
+                compareWithHead.Click += (_, _) =>
+                {
+                    App.ShowWindow(new ViewModels.Compare(repo, tag, repo.CurrentBranch));
+                };
+
+                var compareWith = new MenuItem();
+                compareWith.Header = App.Text("TagCM.CompareWith");
+                compareWith.Icon = App.CreateMenuIcon("Icons.Compare");
+                compareWith.Click += (_, _) =>
+                {
+                    var launcher = App.GetLauncher();
+                    if (launcher != null)
+                        launcher.OpenCommandPalette(new ViewModels.CompareCommandPalette(launcher, repo, tag));
+                };
+
                 var archive = new MenuItem();
                 archive.Icon = App.CreateMenuIcon("Icons.Archive");
                 archive.Header = App.Text("Archive");
@@ -273,6 +291,9 @@ namespace SourceGit.Views
                 menu.Items.Add(pushTag);
                 menu.Items.Add(deleteTag);
                 menu.Items.Add(new MenuItem() { Header = "-" });
+                menu.Items.Add(compareWithHead);
+                menu.Items.Add(compareWith);
+                menu.Items.Add(new MenuItem() { Header = "-" });
                 menu.Items.Add(archive);
                 menu.Items.Add(new MenuItem() { Header = "-" });
 
@@ -346,6 +367,25 @@ namespace SourceGit.Views
             }
             else if (selected.Count > 0)
             {
+                var menu = new ContextMenu();
+
+                if (selected.Count == 2)
+                {
+                    var compare = new MenuItem();
+                    compare.Header = App.Text("TagCM.CompareTwo");
+                    compare.Icon = App.CreateMenuIcon("Icons.Compare");
+                    compare.Click += (_, ev) =>
+                    {
+                        var (based, to) = (selected[0], selected[1]);
+                        if (based.CreatorDate > to.CreatorDate)
+                            (based, to) = (to, based);
+
+                        App.ShowWindow(new ViewModels.Compare(repo, based, to));
+                        ev.Handled = true;
+                    };
+                    menu.Items.Add(compare);
+                }
+
                 var deleteMultiple = new MenuItem();
                 deleteMultiple.Header = App.Text("TagCM.DeleteMultiple", selected.Count);
                 deleteMultiple.Icon = App.CreateMenuIcon("Icons.Clear");
@@ -357,7 +397,6 @@ namespace SourceGit.Views
                     ev.Handled = true;
                 };
 
-                var menu = new ContextMenu();
                 menu.Items.Add(deleteMultiple);
                 menu.Open(listBox);
             }
